0.10.0 (2019-06-02)
===================

New Feature
-----------

- `#5 <https://github.com/shimizukawa/sshh/issues/5>`_: split command into: sshh-agent, sshh-config, ssh-add

   
Bug Fix
-------

- `#4 <https://github.com/shimizukawa/sshh/issues/4>`_: Init bash with temporary rc file to avoid overriding sshh env vars with bashrc (like PS1)


0.9.0 (2019-05-05)
==================

First release.
